Openembedded Core Discussions
 help / color / mirror / Atom feed
* [PATCH] sstatesig: Only squash dependencies for allarch packagegroups
@ 2014-08-19 12:38 Richard Purdie
  0 siblings, 0 replies; only message in thread
From: Richard Purdie @ 2014-08-19 12:38 UTC (permalink / raw)
  To: openembedded-core

The idea of squashing packagegroup dependencies was to avoid allarch 
packages rebuilding upon tune/arch changes. Now that the allarch class
inclusion is conditional, we can narrow down the packagegroup squashing
to be specifically applied to allarch recipes.

Signed-off-by: Richard Purdie <richard.purdie@linuxfoundation.org>

diff --git a/meta/lib/oe/sstatesig.py b/meta/lib/oe/sstatesig.py
index d58147f..4188873 100644
--- a/meta/lib/oe/sstatesig.py
+++ b/meta/lib/oe/sstatesig.py
@@ -14,6 +14,9 @@ def sstate_rundepfilter(siggen, fn, recipename, task, dep, depname, dataCache):
     def isPackageGroup(fn):
         inherits = " ".join(dataCache.inherits[fn])
         return "/packagegroup.bbclass" in inherits
+    def isAllArch(fn):
+        inherits = " ".join(dataCache.inherits[fn])
+        return "/allarch.bbclass" in inherits
     def isImage(fn):
         return "/image.bbclass" in " ".join(dataCache.inherits[fn])
 
@@ -36,8 +39,8 @@ def sstate_rundepfilter(siggen, fn, recipename, task, dep, depname, dataCache):
 
     # Only target packages beyond here
 
-    # packagegroups are assumed to have well behaved names which don't change between architecures/tunes
-    if isPackageGroup(fn):
+    # allarch packagegroups are assumed to have well behaved names which don't change between architecures/tunes
+    if isPackageGroup(fn) and isAllArch(fn):
         return False  
 
     # Exclude well defined machine specific configurations which don't change ABI




^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2014-08-19 12:38 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2014-08-19 12:38 [PATCH] sstatesig: Only squash dependencies for allarch packagegroups Richard Purdie

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox